@@ -11,8 +11,11 @@
 
 #include "debug.h"
 
+#include <KIconColors>
 #include <KIconEngine>
 #include <KIconLoader>
+#include <Plasma/Theme>
+
 #include <QApplication>
 #include <QDBusMessage>
 #include <QDBusPendingCall>
@@ -25,8 +28,6 @@
 #include <QSysInfo>
 #include <QVariantMap>
 
-#include <Plasma/Theme>
-
 #include <netinet/in.h>
 
 #include <dbusmenuimporter.h>
@@ -55,7 +56,6 @@ private:
 StatusNotifierItemSource::StatusNotifierItemSource(const QString &notifierItemId, QObject *parent)
     : QObject(parent)
     , m_customIconLoader(nullptr)
-    , m_menuIconLoader(nullptr)
     , m_menuImporter(nullptr)
     , m_refreshing(false)
     , m_needsReRefreshing(false)
@@ -168,11 +168,6 @@ QString StatusNotifierItemSource::title() const
     return m_title;
 }
 
-QVariant StatusNotifierItemSource::toolTipIcon() const
-{
-    return m_toolTipIcon;
-}
-
 QString StatusNotifierItemSource::toolTipSubTitle() const
 {
     return m_toolTipSubTitle;
@@ -256,12 +251,9 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
         QVariantMap properties = reply.argumentAt<0>();
         QString path = properties[QStringLiteral("IconThemePath")].toString();
 
-        if (!m_customIconLoader || path != m_iconThemePath) {
+        if (!path.isEmpty() && path != m_iconThemePath) {
             if (!m_customIconLoader) {
                 m_customIconLoader = new KIconLoader(QString(), QStringList(), this);
-                m_customIconLoader->setCustomPalette(Plasma::Theme::globalPalette());
-
-                m_menuIconLoader = new KIconLoader(QString(), QStringList(), this);
             }
             // FIXME: If last part of path is not "icons", this won't work!
             QString appName;
@@ -269,26 +261,18 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
             if (tokens.length() >= 3 && tokens.takeLast() == QLatin1String("icons"))
                 appName = tokens.takeLast().toString();
 
-            // icons may be either in the root directory of the passed path or in a
-            // appdir format i.e hicolor/32x32/iconname.png
+            // icons may be either in the root directory of the passed path or in a appdir format
+            // i.e hicolor/32x32/iconname.png
 
             m_customIconLoader->reconfigure(appName, QStringList(path));
-            m_menuIconLoader->reconfigure(appName, QStringList(path));
 
-            // add app dir requires an app name, though this is completely unused in
-            // this context
+            // add app dir requires an app name, though this is completely unused in this context
             m_customIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
-            m_menuIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
 
             connect(m_customIconLoader, &KIconLoader::iconChanged, this, [=, this] {
                 m_customIconLoader->reconfigure(appName, QStringList(path));
                 m_customIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
             });
-
-            connect(m_menuIconLoader, &KIconLoader::iconChanged, this, [=, this] {
-                m_menuIconLoader->reconfigure(appName, QStringList(path));
-                m_menuIconLoader->addAppDir(appName.size() ? appName : QStringLiteral("unused"), path);
-            });
         }
         m_iconThemePath = path;
 
@@ -310,7 +294,7 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
 
             const QString iconName = properties[QStringLiteral("OverlayIconName")].toString();
             if (!iconName.isEmpty()) {
-                overlay = QIcon(new KIconEngine(iconName, iconLoader()));
+                overlay = QIcon(new KIconEngine(iconName, KIconColors(Plasma::Theme::globalPalette()), iconLoader()));
                 if (!overlay.isNull()) {
                     m_overlayIconName = iconName;
                 }
@@ -327,7 +311,7 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
         auto loadIcon = [this, &properties, &overlay](const QString &iconKey, const QString &pixmapKey) -> std::tuple<QIcon, QString> {
             const QString iconName = properties[iconKey].toString();
             if (!iconName.isEmpty()) {
-                QIcon icon = QIcon(new KIconEngine(iconName, iconLoader(), {m_overlayIconName}));
+                QIcon icon = QIcon(new KIconEngine(iconName, KIconColors(Plasma::Theme::globalPalette()), iconLoader(), {m_overlayIconName}));
                 if (!icon.isNull()) {
                     if (!overlay.isNull() && m_overlayIconName.isEmpty()) {
                         overlayIcon(&icon, &overlay);
@@ -357,26 +341,14 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
             if (toolTip.title.isEmpty()) {
                 m_toolTipTitle = QString();
                 m_toolTipSubTitle = QString();
-                m_toolTipIcon = QString();
             } else {
-                QIcon toolTipIcon;
-                if (toolTip.image.size() == 0) {
-                    toolTipIcon = QIcon(new KIconEngine(toolTip.icon, iconLoader()));
-                } else {
-                    toolTipIcon = imageVectorToPixmap(toolTip.image);
-                }
                 m_toolTipTitle = toolTip.title;
                 m_toolTipSubTitle = toolTip.subTitle;
-                if (toolTipIcon.isNull() || toolTipIcon.availableSizes().isEmpty()) {
-                    m_toolTipIcon = QString();
-                } else {
-                    m_toolTipIcon = toolTipIcon;
-                }
             }
         }
 
         // Menu
-        if (!m_menuImporter) {
+        if (qobject_cast<QApplication *>(QCoreApplication::instance()) && !m_menuImporter) {
             QString menuObjectPath = properties[QStringLiteral("Menu")].value<QDBusObjectPath>().path();
             if (!menuObjectPath.isEmpty()) {
                 if (menuObjectPath == QLatin1String("/NO_DBUSMENU")) {
@@ -385,7 +357,7 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
                     // KStatusNotifierItem::setContextMenu().
                     qCWarning(SYSTEM_TRAY) << "DBusMenu disabled for this application";
                 } else {
-                    m_menuImporter = new PlasmaDBusMenuImporter(m_statusNotifierItemInterface->service(), menuObjectPath, m_menuIconLoader, this);
+                    m_menuImporter = new PlasmaDBusMenuImporter(m_statusNotifierItemInterface->service(), menuObjectPath, iconLoader(), this);
                     connect(m_menuImporter, &PlasmaDBusMenuImporter::menuUpdated, this, [this](QMenu *menu) {
                         if (menu == m_menuImporter->menu()) {
                             contextMenuReady();
@@ -402,17 +374,12 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
 
 void StatusNotifierItemSource::reloadIcon()
 {
-    if (m_customIconLoader) {
-        m_customIconLoader->setCustomPalette(Plasma::Theme::globalPalette());
-        m_menuIconLoader->setCustomPalette(Plasma::Theme::globalPalette());
-    }
-
     if (!m_iconName.isEmpty()) {
-        m_icon = QIcon(new KIconEngine(m_iconName, iconLoader(), {m_overlayIconName}));
+        m_icon = QIcon(new KIconEngine(m_iconName, KIconColors(Plasma::Theme::globalPalette()), iconLoader(), {m_overlayIconName}));
     }
 
     if (!m_attentionIconName.isEmpty()) {
-        m_attentionIcon = QIcon(new KIconEngine(m_attentionIconName, iconLoader(), {m_overlayIconName}));
+        m_attentionIcon = QIcon(new KIconEngine(m_attentionIconName, KIconColors(Plasma::Theme::globalPalette()), iconLoader(), {m_overlayIconName}));
     }
 
     Q_EMIT dataUpdated();
