@@ -140,7 +140,7 @@ void GridLayoutManager::resetLayoutFromConfig(const QRectF &newGeom, const QRect
         }
     }
 
-    for (auto *item : qAsConst(missingItems)) {
+    for (auto *item : std::as_const(missingItems)) {
         // NOTE: do not use positionItemAndAssign here, because we do not want to Q_EMIT layoutNeedsSaving, to not save after resize
         maintainItemEdgeAlignment(item, newGeom, oldGeom);
         positionItem(item);
@@ -317,8 +317,8 @@ void GridLayoutManager::adjustToItemSizeHints(ItemContainer *item)
 
 QRect GridLayoutManager::cellBasedGeometry(const QRectF &geom) const
 {
-    return QRect(round(qBound(0.0, geom.x(), layout()->width() - geom.width()) / cellSize().width()),
-                 round(qBound(0.0, geom.y(), layout()->height() - geom.height()) / cellSize().height()),
+    return QRect(round(qBound(0.0, geom.x(), qMax(0.0, layout()->width() - geom.width())) / cellSize().width()),
+                 round(qBound(0.0, geom.y(), qMax(0.0, layout()->height() - geom.height())) / cellSize().height()),
                  round((qreal)geom.width() / cellSize().width()),
                  round((qreal)geom.height() / cellSize().height()));
 }
