@@ -17,7 +17,7 @@
 
 #include "ion_wettercomdebug.h"
 
-#include <KIO/Job>
+#include <KIO/TransferJob>
 #include <KLocalizedString>
 #include <KUnitConversion/Converter>
 
@@ -704,7 +704,7 @@ void WetterComIon::updateWeather(const QString &source, bool parseError)
         data.insert(QStringLiteral("Total Weather Days"), i);
 
         data.insert(QStringLiteral("Credit"), weatherData.credits); // FIXME i18n?
-        data.insert(QStringLiteral("Credit Url"), weatherData.creditsUrl);
+        data.insert(QStringLiteral("Credit Url"), QStringLiteral("%1/place/%2.html").arg(weatherData.creditsUrl).arg(placeInfo.placeCode));
 
         qCDebug(IONENGINE_WETTERCOM) << "updated weather data:" << weatherSource << data;
     } else {
