@@ -79,7 +79,6 @@ LookAndFeelManager::Contents LookAndFeelManager::packageContents(const KPackage:
     Contents contents = Empty;
 
     contents.setFlag(SplashScreen, !pkg.filePath("splashmainscript").isEmpty());
-    contents.setFlag(LockScreen, !pkg.filePath("lockscreenmainscript").isEmpty());
 
     contents.setFlag(DesktopLayout, !pkg.filePath("layouts").isEmpty());
 
@@ -137,15 +136,6 @@ void LookAndFeelManager::setSplashScreen(const QString &theme)
     writeNewDefaults(group, defaultGroup, QStringLiteral("Engine"), QStringLiteral("KSplashQML"));
 }
 
-void LookAndFeelManager::setLockScreen(const QString &theme)
-{
-    if (theme.isEmpty()) {
-        return;
-    }
-
-    writeNewDefaults(QStringLiteral("kscreenlockerrc"), QStringLiteral("Greeter"), QStringLiteral("Theme"), theme);
-}
-
 void LookAndFeelManager::setWindowSwitcher(const QString &theme)
 {
     if (theme.isEmpty()) {
@@ -588,9 +578,6 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
                 setSplashScreen(m_data->settings()->lookAndFeelPackage());
             }
         }
-        if (itemsToApply.testFlag(LockScreen)) {
-            setLockScreen(m_data->settings()->lookAndFeelPackage());
-        }
 
         QFile packageFile(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/kdedefaults/package"));
         packageFile.open(QIODevice::WriteOnly);
