@@ -27,7 +27,6 @@
 
 using namespace Qt::StringLiterals;
 
-static const QString s_plasmaWorkspaceNotifyRcName = QStringLiteral("plasma_workspace");
 static const QRegularExpression s_eventGroupRegExp(QStringLiteral("^Event/([^/]*)$"));
 
 SourcesModel::SourcesModel(QObject *parent)
@@ -66,6 +65,16 @@ QPersistentModelIndex SourcesModel::persistentIndexForNotifyRcName(const QString
     return QPersistentModelIndex(matches.first());
 }
 
+QPersistentModelIndex SourcesModel::indexOfEvent(const QModelIndex &parent, const QString &eventId) const
+{
+    if (!checkIndex(parent, CheckIndexOption::IndexIsValid | CheckIndexOption::ParentIsInvalid) || !hasChildren(parent)) {
+        return QPersistentModelIndex();
+    }
+
+    const auto matches = match(index(0, 0, parent), EventIdRole, eventId, 1, Qt::MatchFixedString);
+    return matches.isEmpty() ? QPersistentModelIndex() : QPersistentModelIndex(matches.first());
+}
+
 int SourcesModel::columnCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
@@ -104,6 +113,8 @@ QVariant SourcesModel::data(const QModelIndex &index, int role) const
             return event->name();
         case Qt::DecorationRole:
             return event->iconName();
+        case EventIdRole:
+            return s_eventGroupRegExp.match(event->currentGroup()).captured(1);
         case CommentRole:
             return event->comment();
         case ActionsRole:
@@ -261,6 +272,7 @@ QHash<int, QByteArray> SourcesModel::roleNames() const
         {NotifyRcNameRole, QByteArrayLiteral("notifyRcName")},
         {DesktopEntryRole, QByteArrayLiteral("desktopEntry")},
         {IsDefaultRole, QByteArrayLiteral("isDefault")},
+        {EventIdRole, QByteArrayLiteral("eventId")},
         {CommentRole, QByteArrayLiteral("comment")},
         {ShowIconsRole, QByteArrayLiteral("showIcons")},
         {ActionsRole, QByteArrayLiteral("actions")},
@@ -399,14 +411,7 @@ void SourcesModel::load()
         .events = {},
     };
 
-    // Sort and make sure plasma_workspace is at the beginning of the list
     std::sort(servicesData.begin(), servicesData.end(), [&collator](const SourceData &a, const SourceData &b) {
-        if (a.notifyRcName == s_plasmaWorkspaceNotifyRcName) {
-            return true;
-        }
-        if (b.notifyRcName == s_plasmaWorkspaceNotifyRcName) {
-            return false;
-        }
         return collator.compare(a.display(), b.display()) < 0;
     });
 
