@@ -1,21 +1,7 @@
 /*
-    Copyright 2020  Devin Lin <espidev@gmail.com>
+    SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "fprintdevice.h"
@@ -24,8 +10,7 @@ FprintDevice::FprintDevice(QDBusObjectPath path, QObject *parent)
     : QObject(parent)
     , m_devicePath(path.path())
     , m_fprintInterface(new NetReactivatedFprintDeviceInterface(QStringLiteral("net.reactivated.Fprint"), path.path(), QDBusConnection::systemBus(), this))
-    , m_freedesktopInterface(
-          new QDBusInterface(QStringLiteral("net.reactivated.Fprint"), path.path(), "org.freedesktop.DBus.Properties", QDBusConnection::systemBus(), this))
+    , m_properiesInterface(new OrgFreedesktopDBusPropertiesInterface(QStringLiteral("net.reactivated.Fprint"), path.path(), QDBusConnection::systemBus(), this))
 {
     connect(m_fprintInterface, &NetReactivatedFprintDeviceInterface::EnrollStatus, this, &FprintDevice::enrollStatus);
 }
@@ -49,14 +34,7 @@ QDBusError FprintDevice::release()
     return reply.error();
 }
 
-QDBusError FprintDevice::deleteEnrolledFingers()
-{
-    auto reply = m_fprintInterface->DeleteEnrolledFingers2();
-    reply.waitForFinished();
-    return reply.error();
-}
-
-QDBusError FprintDevice::deleteEnrolledFinger(QString &finger)
+QDBusError FprintDevice::deleteEnrolledFinger(const QString &finger)
 {
     auto reply = m_fprintInterface->DeleteEnrolledFinger(finger);
     reply.waitForFinished();
@@ -77,7 +55,7 @@ QDBusError FprintDevice::stopEnrolling()
     return reply.error();
 }
 
-void FprintDevice::enrollStatus(QString result, bool done)
+void FprintDevice::enrollStatus(const QString &result, bool done)
 {
     Q_UNUSED(done)
 
@@ -95,7 +73,7 @@ void FprintDevice::enrollStatus(QString result, bool done)
 
 int FprintDevice::numOfEnrollStages()
 {
-    QDBusReply<QDBusVariant> reply = m_freedesktopInterface->call("Get", "net.reactivated.Fprint.Device", "num-enroll-stages");
+    QDBusReply<QDBusVariant> reply = m_properiesInterface->Get("net.reactivated.Fprint.Device", "num-enroll-stages");
     if (!reply.isValid()) {
         qDebug() << "error fetching num-enroll-stages:" << reply.error();
         return 0;
@@ -105,7 +83,7 @@ int FprintDevice::numOfEnrollStages()
 
 FprintDevice::ScanType FprintDevice::scanType()
 {
-    QDBusReply<QDBusVariant> reply = m_freedesktopInterface->call("Get", "net.reactivated.Fprint.Device", "scan-type");
+    QDBusReply<QDBusVariant> reply = m_properiesInterface->Get("net.reactivated.Fprint.Device", "scan-type");
     if (!reply.isValid()) {
         qDebug() << "error fetching scan-type:" << reply.error();
         return FprintDevice::Press;
@@ -128,7 +106,7 @@ FprintDevice::ScanType FprintDevice::scanType()
 
 bool FprintDevice::fingerPresent()
 {
-    QDBusReply<QDBusVariant> reply = m_freedesktopInterface->call("Get", "net.reactivated.Fprint.Device", "finger-present");
+    QDBusReply<QDBusVariant> reply = m_properiesInterface->Get("net.reactivated.Fprint.Device", "finger-present");
     if (!reply.isValid()) {
         qDebug() << "error fetching finger-present:" << reply.error();
         return "";
@@ -138,7 +116,7 @@ bool FprintDevice::fingerPresent()
 
 bool FprintDevice::fingerNeeded()
 {
-    QDBusReply<QDBusVariant> reply = m_freedesktopInterface->call("Get", "net.reactivated.Fprint.Device", "finger-needed");
+    QDBusReply<QDBusVariant> reply = m_properiesInterface->Get("net.reactivated.Fprint.Device", "finger-needed");
     if (!reply.isValid()) {
         qDebug() << "error fetching finger-needed:" << reply.error();
         return "";
