@@ -8,6 +8,8 @@
 #include "tasktools.h"
 #include "abstracttasksmodel.h"
 
+#include <ranges>
+
 #include <KApplicationTrader>
 #include <KConfigGroup>
 #include <KDesktopFile>
@@ -169,8 +171,9 @@ AppData appDataFromUrl(const QUrl &url, const QIcon &fallbackIcon)
     return data;
 }
 
-QUrl windowUrlFromMetadata(const QString &appId, quint32 pid, KSharedConfig::Ptr rulesConfig, const QString &xWindowsWMClassName)
+QUrl windowUrlFromMetadata(const QString &appId, quint32 pid, const KSharedConfig::Ptr &rulesConfig, const QString &xWindowsWMClassName)
 {
+    static_assert(!std::is_trivially_copy_assignable_v<KSharedConfig::Ptr>);
     if (!rulesConfig) {
         return QUrl();
     }
@@ -471,7 +474,7 @@ QUrl windowUrlFromMetadata(const QString &appId, quint32 pid, KSharedConfig::Ptr
     return url;
 }
 
-KService::List servicesFromPid(quint32 pid, KSharedConfig::Ptr rulesConfig)
+KService::List servicesFromPid(quint32 pid, const KSharedConfig::Ptr &rulesConfig)
 {
     if (pid == 0) {
         return KService::List();
@@ -486,18 +489,20 @@ KService::List servicesFromPid(quint32 pid, KSharedConfig::Ptr rulesConfig)
     if (environFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
         constexpr QByteArrayView bamfDesktopFileHint{"BAMF_DESKTOP_FILE_HINT"};
         constexpr QByteArrayView appDir{"APPDIR"};
-        const auto lines = environFile.readAll().split('\0');
-        for (const QByteArrayView line : lines) {
-            const int equalsIdx = line.indexOf('=');
-            if (equalsIdx <= 0) {
+        const QByteArray environ = environFile.readAll();
+#if (defined(__GNUC__) && __GNUC__ >= 12) || !defined(__GNUC__)
+        for (const QByteArrayView line : QByteArrayView(environ) | std::views::split('\0')) {
+#else
+        for (const QByteArrayView line : environ.split('\0')) {
+#endif
+            const auto equalsIdx = line.indexOf('=');
+            if (equalsIdx == -1) {
                 continue;
             }
 
             const QByteArrayView key = line.sliced(0, equalsIdx);
             if (key == bamfDesktopFileHint) {
-                const QByteArrayView value = line.sliced(equalsIdx + 1);
-
-                KService::Ptr service = KService::serviceByDesktopPath(QString::fromUtf8(value));
+                KService::Ptr service = KService::serviceByDesktopPath(QString::fromUtf8(line.sliced(equalsIdx + 1)));
                 if (service) {
                     return {service};
                 }
@@ -528,7 +533,7 @@ KService::List servicesFromPid(quint32 pid, KSharedConfig::Ptr rulesConfig)
     return servicesFromCmdLine(cmdLine, proc.name(), rulesConfig);
 }
 
-KService::List servicesFromCmdLine(const QString &_cmdLine, const QString &processName, KSharedConfig::Ptr rulesConfig)
+KService::List servicesFromCmdLine(const QString &_cmdLine, const QString &processName, const KSharedConfig::Ptr &rulesConfig)
 {
     QString cmdLine = _cmdLine;
     KService::List services;
