@@ -63,7 +63,7 @@ void Greeter::init()
 void Greeter::enableWindowed()
 {
     m_windowed = true;
-    promptLogout();
+    promptAll();
 }
 
 void Greeter::adoptScreen(QScreen *screen)
@@ -140,3 +140,12 @@ void Greeter::promptReboot()
     m_shutdownType = KWorkSpace::ShutdownTypeReboot;
     init();
 }
+
+void Greeter::promptAll()
+{
+    if (m_running) {
+        return;
+    }
+    m_shutdownType = KWorkSpace::ShutdownTypeDefault;
+    init();
+}
