@@ -27,7 +27,7 @@ QList<BookmarkMatch> Opera::match(const QString &term, bool addEverything)
     QLatin1String descriptionStart("\tDESCRIPTION=");
 
     // search
-    for (const QString &entry : qAsConst(m_operaBookmarkEntries)) {
+    for (const QString &entry : std::as_const(m_operaBookmarkEntries)) {
         QStringList entryLines = entry.split(QStringLiteral("\n"));
         if (!entryLines.first().startsWith(QLatin1String("#URL"))) {
             continue; // skip folder entries
@@ -38,7 +38,7 @@ QList<BookmarkMatch> Opera::match(const QString &term, bool addEverything)
         QString url;
         QString description;
 
-        for (const QString &line : qAsConst(entryLines)) {
+        for (const QString &line : std::as_const(entryLines)) {
             if (line.startsWith(nameStart)) {
                 name = line.mid(QString(nameStart).length()).simplified();
             } else if (line.startsWith(urlStart)) {
