@@ -54,8 +54,6 @@ namespace KWayland
 {
 namespace Client
 {
-class PlasmaShell;
-class PlasmaShellSurface;
 class PlasmaWindow;
 class PlasmaWindowManagement;
 }
@@ -66,6 +64,7 @@ class ShellCorona : public Plasma::Corona, QDBusContext
     Q_OBJECT
     Q_PROPERTY(QString shell READ shell WRITE setShell)
     Q_PROPERTY(int numScreens READ numScreens)
+    Q_PROPERTY(PanelView *panelBeingConfigured READ panelBeingConfigured NOTIFY panelBeingConfiguredChanged)
     Q_CLASSINFO("D-Bus Interface", "org.kde.PlasmaShell")
 
 public:
@@ -108,8 +107,6 @@ public:
      */
     Plasma::Containment *createContainmentForActivity(const QString &activity, int screenNum);
 
-    KWayland::Client::PlasmaShell *waylandPlasmaShellInterface() const;
-
     ScreenPool *screenPool() const;
 
     QList<int> screenIds() const;
@@ -143,6 +140,8 @@ public:
 
     Q_INVOKABLE void showAddPanelContextMenu(const QPoint pos);
 
+    PanelView *panelBeingConfigured() const;
+
 Q_SIGNALS:
     void glInitializationFailed();
     // A preview for this containment has been rendered and saved to disk
@@ -153,6 +152,7 @@ Q_SIGNALS:
     void screenOrderChanged(QList<QScreen *> screens);
 
     void wallpaperChanged(uint screenNum);
+    void panelBeingConfiguredChanged();
 
 public Q_SLOTS:
     /**
@@ -296,8 +296,6 @@ private:
     std::unique_ptr<QMenu> m_addPanelsMenu;
     KPackage::Package m_lookAndFeelPackage;
 
-    // Used to restore the previous activated window after the panel loses focus
-    KWayland::Client::PlasmaShellSurface *m_shellSurface = nullptr;
 #if HAVE_X11
     WId m_previousWId = 0;
 #endif
@@ -308,7 +306,6 @@ private:
 #ifndef NDEBUG
     QTimer m_invariantsTimer;
 #endif
-    KWayland::Client::PlasmaShell *m_waylandPlasmaShell;
     // For getting the active window on Wayland
     KWayland::Client::PlasmaWindowManagement *m_waylandWindowManagement = nullptr;
     QPointer<KWayland::Client::PlasmaWindow> m_previousPlasmaWindow;
