@@ -13,8 +13,6 @@
 
 #include <unistd.h>
 
-#include <chrono>
-
 #include "debug_p.h"
 #include "waiter.h"
 
@@ -64,7 +62,7 @@ Waiter::Waiter(int argc, char **argv)
     }
     if (timeout > 0) {
         mTimeoutTimer.setSingleShot(true);
-        mTimeoutTimer.setInterval(std::chrono::seconds(timeout));
+        mTimeoutTimer.setInterval(timeout * 1000);
         connect(&mTimeoutTimer, &QTimer::timeout, this, &Waiter::timeout);
         mTimeoutTimer.start();
     }
