@@ -14,7 +14,6 @@
 #include <QDBusMessage>
 #include <QDebug>
 #include <QFileInfo>
-#include <QTimer>
 
 int main(int argc, char **argv)
 {
@@ -24,17 +23,17 @@ int main(int argc, char **argv)
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("plasma-apply-wallpaperimage"));
 
-    QCommandLineParser *parser = new QCommandLineParser;
-    parser->addHelpOption();
-    parser->setApplicationDescription(i18n("This tool allows you to set an image as the wallpaper for the Plasma session."));
-    parser->addPositionalArgument(QStringLiteral("imagefile"),
-                                  i18n("An image file or an installed wallpaper kpackage that you wish to set as the wallpaper for your Plasma session"));
-    parser->process(app);
+    QCommandLineParser parser;
+    parser.addHelpOption();
+    parser.setApplicationDescription(i18n("This tool allows you to set an image as the wallpaper for the Plasma session."));
+    parser.addPositionalArgument(QStringLiteral("imagefile"),
+                                 i18n("An image file or an installed wallpaper kpackage that you wish to set as the wallpaper for your Plasma session"));
+    parser.process(app);
 
-    int errorCode{0};
+    int errorCode{EXIT_SUCCESS};
     QTextStream ts(stdout);
-    if (!parser->positionalArguments().isEmpty()) {
-        QString wallpaperFile{parser->positionalArguments().first()};
+    if (!parser.positionalArguments().isEmpty()) {
+        QString wallpaperFile{parser.positionalArguments().first()};
         QFileInfo wallpaperInfo{wallpaperFile};
         bool isWallpaper{false};
         bool isKPackage{false};
@@ -46,7 +45,7 @@ int main(int argc, char **argv)
                 "file yourself: %1",
                 wallpaperFile)
                << Qt::endl;
-            errorCode = -1;
+            errorCode = EXIT_FAILURE;
         } else {
             if (wallpaperInfo.exists()) {
                 if (wallpaperInfo.isFile()) {
@@ -68,11 +67,11 @@ int main(int argc, char **argv)
         if (isWallpaper) {
             QString script;
             QTextStream out(&script);
-            out << "for (var key in desktops()) {"
-                << "var d = desktops()[key];"
-                << "d.wallpaperPlugin = 'org.kde.image';"
-                << "d.currentConfigGroup = ['Wallpaper', 'org.kde.image', 'General'];"
-                << "d.writeConfig('Image', 'file://" + wallpaperFile + "');"
+            out << "for (var key in desktops()) {" //
+                << "var d = desktops()[key];" //
+                << "d.wallpaperPlugin = 'org.kde.image';" //
+                << "d.currentConfigGroup = ['Wallpaper', 'org.kde.image', 'General'];" //
+                << "d.writeConfig('Image', 'file://" + wallpaperFile + "');" //
                 << "}";
             auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
                                                           QStringLiteral("/PlasmaShell"),
@@ -83,7 +82,7 @@ int main(int argc, char **argv)
 
             if (reply.type() == QDBusMessage::ErrorMessage) {
                 ts << i18n("An error occurred while attempting to set the Plasma wallpaper:\n") << reply.errorMessage() << Qt::endl;
-                errorCode = -1;
+                errorCode = EXIT_FAILURE;
             } else {
                 if (isKPackage) {
                     ts << i18n("Successfully set the wallpaper for all desktops to the KPackage based %1", wallpaperFile) << Qt::endl;
@@ -92,17 +91,14 @@ int main(int argc, char **argv)
                 }
             }
 
-        } else if (errorCode == 0) {
+        } else if (errorCode == EXIT_SUCCESS) {
             // Just to avoid spitting out multiple errors
             ts << i18n("The file passed to be set as wallpaper does not exist, or we cannot identify it as a wallpaper: %1", wallpaperFile) << Qt::endl;
-            errorCode = -1;
+            errorCode = EXIT_FAILURE;
         }
     } else {
-        parser->showHelp();
+        parser.showHelp();
     }
-    QTimer::singleShot(0, &app, [&app, &errorCode]() {
-        app.exit(errorCode);
-    });
 
-    return app.exec();
+    return errorCode;
 }
