@@ -12,13 +12,8 @@
 #include <xcb/xcb_atom.h>
 #include <xcb/xcb_event.h>
 
-#include "debug.h"
-#include "xcbutils.h"
-
-#include <QGuiApplication>
 #include <QScreen>
 #include <QTimer>
-#include <private/qtx11extras_p.h>
 
 #include <QBitmap>
 
@@ -30,13 +25,22 @@
 #include "statusnotifierwatcher_interface.h"
 
 #include "../c_ptr.h"
+#include "debug.h"
+#include "xcbutils.h"
 #include "xtestsender.h"
+#include <X11/Xlib.h>
 
 // #define VISUAL_DEBUG
 
 #define SNI_WATCHER_SERVICE_NAME "org.kde.StatusNotifierWatcher"
 #define SNI_WATCHER_PATH "/StatusNotifierWatcher"
 
+#ifdef Status
+typedef Status XStatus;
+#undef Status
+typedef XStatus Status;
+#endif
+
 static uint16_t s_embedSize = 32; // max size of window to embed. We no longer resize the embedded window as Chromium acts stupidly.
 static unsigned int XEMBED_VERSION = 0;
 
@@ -55,7 +59,7 @@ void xembed_message_send(xcb_window_t towin, long message, long d1, long d2, lon
     ev.data.data32[3] = d2;
     ev.data.data32[4] = d3;
     ev.type = Xcb::atoms->xembedAtom;
-    xcb_send_event(QX11Info::connection(), false, towin, XCB_EVENT_MASK_NO_EVENT, (char *)&ev);
+    xcb_send_event(qGuiApp->nativeInterface<QNativeInterface::QX11Application>()->connection(), false, towin, XCB_EVENT_MASK_NO_EVENT, (char *)&ev);
 }
 
 SNIProxy::SNIProxy(xcb_window_t wid, QObject *parent)
@@ -65,8 +69,8 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject *parent)
     // there is an undocumented feature that you can register an SNI by path, however it doesn't detect an object on a service being removed, only the entire
     // service closing instead lets use one DBus connection per SNI
     m_dbus(QDBusConnection::connectToBus(QDBusConnection::SessionBus, QStringLiteral("XembedSniProxy%1").arg(s_serviceCount++)))
+    , m_x11Interface(qGuiApp->nativeInterface<QNativeInterface::QX11Application>())
     , m_windowId(wid)
-    , sendingClickEvent(false)
     , m_injectMode(Direct)
 {
     // create new SNI
@@ -81,7 +85,7 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject *parent)
         qCWarning(SNIPROXY) << "could not register SNI:" << reply.error().message();
     }
 
-    auto c = QX11Info::connection();
+    auto c = m_x11Interface->connection();
 
     // create a container window
     auto screen = xcb_setup_roots_iterator(xcb_get_setup(c)).data;
@@ -90,9 +94,7 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject *parent)
     uint32_t mask = XCB_CW_BACK_PIXEL | XCB_CW_OVERRIDE_REDIRECT | XCB_CW_EVENT_MASK;
     values[0] = screen->black_pixel; // draw a solid background so the embedded icon doesn't get garbage in it
     values[1] = true; // bypass wM
-    values[2] = XCB_EVENT_MASK_VISIBILITY_CHANGE | // receive visibility change, to handle KWin restart #357443
-                                                   // Redirect and handle structure (size, position) requests from the embedded window.
-        XCB_EVENT_MASK_STRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_REDIRECT;
+    values[2] = XCB_EVENT_MASK_STRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_REDIRECT;
     xcb_create_window(c, /* connection    */
                       XCB_COPY_FROM_PARENT, /* depth         */
                       m_containerWid, /* window Id     */
@@ -113,14 +115,13 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject *parent)
         We also need it to exist in the right place to get the clicks working as GTK will check sendEvent locations to see if our window is in the right place.
        So even though our contents are drawn via compositing we still put this window in the right place
 
-        We can't composite it away anything parented owned by the root window (apparently)
-        Stack Under works in the non composited case, but it doesn't seem to work in kwin's composited case (probably need set relevant NETWM hint)
-
-        As a last resort set opacity to 0 just to make sure this container never appears
+        Set opacity to 0 just to make sure this container never appears
+        And set the input region to null so everything just clicks through
     */
 
+    setActiveForInput(false);
+
 #ifndef VISUAL_DEBUG
-    stackContainerWindow(XCB_STACK_MODE_BELOW);
 
     NETWinInfo wm(c, m_containerWid, screen->root, NET::Properties(), NET::Properties2());
     wm.setOpacity(0);
@@ -180,9 +181,7 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject *parent)
 
 SNIProxy::~SNIProxy()
 {
-    auto c = QX11Info::connection();
-
-    xcb_destroy_window(c, m_containerWid);
+    xcb_destroy_window(m_x11Interface->connection(), m_containerWid);
     QDBusConnection::disconnectFromBus(m_dbus.name());
 }
 
@@ -208,7 +207,7 @@ void SNIProxy::update()
 
 void SNIProxy::resizeWindow(const uint16_t width, const uint16_t height) const
 {
-    auto connection = QX11Info::connection();
+    auto connection = m_x11Interface->connection();
 
     uint16_t widthNormalized = std::min(width, s_embedSize);
     uint16_t heighNormalized = std::min(height, s_embedSize);
@@ -219,17 +218,9 @@ void SNIProxy::resizeWindow(const uint16_t width, const uint16_t height) const
     xcb_flush(connection);
 }
 
-void SNIProxy::hideContainerWindow(xcb_window_t windowId) const
-{
-    if (m_containerWid == windowId && !sendingClickEvent) {
-        qDebug() << "Container window visible, stack below";
-        stackContainerWindow(XCB_STACK_MODE_BELOW);
-    }
-}
-
 QSize SNIProxy::calculateClientWindowSize() const
 {
-    auto c = QX11Info::connection();
+    auto c = m_x11Interface->connection();
 
     auto cookie = xcb_get_geometry(c, m_windowId);
     UniqueCPointer<xcb_get_geometry_reply_t> clientGeom(xcb_get_geometry_reply(c, cookie, nullptr));
@@ -283,7 +274,7 @@ bool SNIProxy::isTransparentImage(const QImage &image) const
 
 QImage SNIProxy::getImageNonComposite() const
 {
-    auto c = QX11Info::connection();
+    auto c = m_x11Interface->connection();
 
     QSize clientWindowSize = calculateClientWindowSize();
 
@@ -379,9 +370,10 @@ QImage SNIProxy::convertFromNative(xcb_image_t *xcbImage) const
 */
 QPoint SNIProxy::calculateClickPoint() const
 {
-    QPoint clickPoint = QPoint(0, 0);
+    QSize clientSize = calculateClientWindowSize();
+    QPoint clickPoint = QPoint(clientSize.width() / 2, clientSize.height() / 2);
 
-    auto c = QX11Info::connection();
+    auto c = m_x11Interface->connection();
 
     // request extent to check if shape has been set
     xcb_shape_query_extents_cookie_t extentsCookie = xcb_shape_query_extents(c, m_windowId);
@@ -416,11 +408,30 @@ QPoint SNIProxy::calculateClickPoint() const
     return clickPoint;
 }
 
-void SNIProxy::stackContainerWindow(const uint32_t stackMode) const
+void SNIProxy::setActiveForInput(bool active) const
 {
-    auto c = QX11Info::connection();
-    const uint32_t stackData[] = {stackMode};
-    xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_STACK_MODE, stackData);
+    auto c = m_x11Interface->connection();
+    if (active) {
+        xcb_rectangle_t rectangle;
+        rectangle.x = 0;
+        rectangle.y = 0;
+        rectangle.width = s_embedSize;
+        rectangle.height = s_embedSize;
+        xcb_shape_rectangles(c, XCB_SHAPE_SO_SET, XCB_SHAPE_SK_INPUT, 0, m_containerWid, 0, 0, 1, &rectangle);
+
+        const uint32_t stackData[] = {XCB_STACK_MODE_ABOVE};
+        xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_STACK_MODE, stackData);
+    } else {
+        xcb_rectangle_t rectangle;
+        rectangle.x = 0;
+        rectangle.y = 0;
+        rectangle.width = 0;
+        rectangle.height = 0;
+        xcb_shape_rectangles(c, XCB_SHAPE_SO_SET, XCB_SHAPE_SK_INPUT, 0, m_containerWid, 0, 0, 1, &rectangle);
+
+        const uint32_t stackData[] = {XCB_STACK_MODE_BELOW};
+        xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_STACK_MODE, stackData);
+    }
 }
 
 //____________properties__________
@@ -504,9 +515,8 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
     // ideally we should make this match the plasmoid hit area
 
     qCDebug(SNIPROXY) << "Received click" << mouseButton << "with passed x*y" << x << y;
-    sendingClickEvent = true;
 
-    auto c = QX11Info::connection();
+    auto c = m_x11Interface->connection();
 
     auto cookieSize = xcb_get_geometry(c, m_windowId);
     UniqueCPointer<xcb_get_geometry_reply_t> clientGeom(xcb_get_geometry_reply(c, cookieSize, nullptr));
@@ -522,6 +532,7 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
     // move our window so the mouse is within its geometry
     uint32_t configVals[2] = {0, 0};
     const QPoint clickPoint = calculateClickPoint();
+
     if (mouseButton >= XCB_BUTTON_INDEX_4) {
         // scroll event, take pointer position
         auto cookie = xcb_query_pointer(c, m_windowId);
@@ -534,8 +545,7 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
     }
     xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_X | XCB_CONFIG_WINDOW_Y, configVals);
 
-    // pull window up
-    stackContainerWindow(XCB_STACK_MODE_ABOVE);
+    setActiveForInput(true);
 
     // mouse down
     if (m_injectMode == Direct) {
@@ -543,9 +553,9 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
         memset(event, 0x00, sizeof(xcb_button_press_event_t));
         event->response_type = XCB_BUTTON_PRESS;
         event->event = m_windowId;
-        event->time = QX11Info::getTimestamp();
+        event->time = XCB_CURRENT_TIME;
         event->same_screen = 1;
-        event->root = QX11Info::appRootWindow();
+        event->root = DefaultRootWindow(m_x11Interface->display());
         event->root_x = x;
         event->root_y = y;
         event->event_x = static_cast<int16_t>(clickPoint.x());
@@ -557,7 +567,7 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
         xcb_send_event(c, false, m_windowId, XCB_EVENT_MASK_BUTTON_PRESS, (char *)event);
         delete event;
     } else {
-        sendXTestPressed(QX11Info::display(), mouseButton);
+        sendXTestPressed(m_x11Interface->display(), mouseButton);
     }
 
     // mouse up
@@ -566,9 +576,9 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
         memset(event, 0x00, sizeof(xcb_button_release_event_t));
         event->response_type = XCB_BUTTON_RELEASE;
         event->event = m_windowId;
-        event->time = QX11Info::getTimestamp();
+        event->time = XCB_CURRENT_TIME;
         event->same_screen = 1;
-        event->root = QX11Info::appRootWindow();
+        event->root = DefaultRootWindow(m_x11Interface->display());
         event->root_x = x;
         event->root_y = y;
         event->event_x = static_cast<int16_t>(clickPoint.x());
@@ -580,12 +590,8 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
         xcb_send_event(c, false, m_windowId, XCB_EVENT_MASK_BUTTON_RELEASE, (char *)event);
         delete event;
     } else {
-        sendXTestReleased(QX11Info::display(), mouseButton);
+        sendXTestReleased(m_x11Interface->display(), mouseButton);
     }
 
-#ifndef VISUAL_DEBUG
-    stackContainerWindow(XCB_STACK_MODE_BELOW);
-#endif
-
-    sendingClickEvent = false;
+    setActiveForInput(false);
 }
